## Rebuild options:
# --with hal : Build with hal support (default: without)
#              use bcond_without to change the default
%bcond_with hal

Name:           emelfm2
Version:        0.8.1
Release:        1%{?dist}
Summary:        File manager that implements the popular two-pane design

Group:          Applications/File
License:        GPLv3+
URL:            http://emelfm2.net/
Source0:        http://emelfm2.net/rel/%{name}-%{version}.tar.bz2
#VCS svn:http://svn.emelfm2.net/trunk/
Patch0:         emelfm2-0.7.1-dsofix.patch
# position cursor at start of opened file, taken from SVN r2490
Patch1:         emelfm2-0.8.1-cursor-position.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  dbus-glib-devel
BuildRequires:  file-devel
BuildRequires:  gtk2-devel >= 2.6.0
BuildRequires:  libacl-devel
BuildRequires:  gettext
BuildRequires:  desktop-file-utils
Requires:       findutils >= 4.2, grep, sed, bzip2
%if %{with hal}
BuildRequires:  hal-devel, dbus-glib-devel
Requires:       hal
%endif

# only available in Fedora >= 11
%if 0%{?fedora} > 10
BuildRequires:  gtkspell-devel >= 2.0.14
%endif

# Fedora 13 uses udisks
%if 0%{?fedora} > 12
BuildRequires:  udisks-devel
Requires:       udisks
%else
# Fedora 11 uses DeviceKit
%if 0%{?fedora} > 10
BuildRequires:  DeviceKit-disks-devel
Requires:       DeviceKit-disks
%endif
%endif

%description
emelFM2 is the GTK+2 port of emelFM. emelFM2 is a file manager that implements 
the popular two-pane design. It features a simple GTK+2 interface, a flexible 
file typing scheme, and a built-in command line for executing commands without 
opening an xterm.


%prep
%setup -q
%patch0 -p1 -b .dsofix
%patch1 -p0 -b .cursor-position

# fix broken icon in emelfm2.desktop
sed -i 's!Icon=emelfm2!Icon=%{_datadir}/pixmaps/emelfm2/emelfm2_48.png!' \
    docs/desktop_environment/%{name}.desktop

# get more useful build logs (verify CFLAGS etc)
sed -i 's!^\(\t\+\)@!\1!' Makefile


%build
make %{?_smp_mflags} \
    CFLAGS="${RPM_OPT_FLAGS}" \
    PREFIX="%{_prefix}" \
    LIB_DIR="%{_libdir}" \
    DOCS_VERSION=1 \
    WITH_TRANSPARENCY=1 \
    WITH_KERNELFAM=1 \
    WITH_TRACKER=1 \
    USE_LATEST=1 \
    WITH_GTK2=1 \
    NEW_COMMAND=1 \
    WITH_ACL=1 \
    WITH_POLKIT=1 \
    WITH_CUSTOMMOUSE=1 \
    STRIP=0 \
    %if 0%{?fedora} > 10
      EDITOR_SPELLCHECK=1 \
    %endif
    %if 0%{?fedora} > 11
      WITH_POLKIT=1 \
      WITH_UDISKS=1 \
    %endif
    %if %{with hal}
      WITH_HAL=1 \
    %endif


%install
rm -rf $RPM_BUILD_ROOT
make install install_i18n \
    DOCS_VERSION=1 \
    PREFIX=$RPM_BUILD_ROOT%{_prefix} \
    PLUGINS_DIR="$RPM_BUILD_ROOT%{_libdir}/%{name}/plugins"

%find_lang %{name}

desktop-file-install --vendor fedora                            \
        --dir ${RPM_BUILD_ROOT}%{_datadir}/applications         \
        --delete-original                                       \
        ${RPM_BUILD_ROOT}%{_datadir}/applications/%{name}.desktop


%clean
rm -rf $RPM_BUILD_ROOT


%files -f %{name}.lang
%defattr(-,root,root,-)
%doc docs/ACTIONS docs/CONFIGURATION docs/CREDITS docs/HACKING 
%doc docs/NEWS docs/README docs/TODO docs/USAGE docs/WARNING 
%doc docs/GPL docs/LGPL
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/applications/fedora-%{name}.desktop
%{_datadir}/application-registry/%{name}.applications
%{_datadir}/pixmaps/%{name}
%{_mandir}/man1/emelfm2.1.gz


%changelog
* Tue Apr 24 2012 Christoph Wickert <cwickert@fedoraproject.org> - 0.8.1-1
- Update to 0.8.1
- Patch editor to position cursor at start of opened file (instead of end)
- Explicitly build GTK2 version for now
- Add VCS key

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Jun 16 2011 Christoph Wickert <cwickert@fedoraproject.org> - 0.8.0-1
- Update to 0.8.0

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Feb 04 2011 Christoph Wickert <cwickert@fedoraproject.org> - 0.7.5-1
- Update to 0.7.5

* Sun Nov 28 2010 Christoph Wickert <cwickert@fedoraproject.org> - 0.7.4-1
- Update to 0.7.4

* Fri Jun 18 2010 Christoph Wickert <cwickert@fedoraproject.org> - 0.7.3-1
- Update to 0.7.3
- Add udisks support

* Thu Feb 25 2010 Christoph Wickert <cwickert@fedoraproject.org> - 0.7.1-2
- Add patch to fix DSO linking (#564729)

* Mon Dec 21 2009 Christoph Wickert <cwickert@fedoraproject.org> - 0.7.1-1
- Update to 0.7.1

* Sun Nov 22 2009 Christoph Wickert <cwickert@fedoraproject.org> - 0.7.0-1
- Update to 0.7.0

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jul 21 2009 Christoph Wickert <cwickert@fedoraproject.org> - 0.6.2-2
- Fix a typo that prefented the debuginfo from being built (#513031)

* Mon Jul 20 2009 Christoph Wickert <cwickert@fedoraproject.org> - 0.6.2-1
- Update to 0.6.2

* Fri Jul 17 2009 Christoph Wickert <cwickert@fedoraproject.org> - 0.6.1-2
- Build with ACL plugin again, got dropped accidentially.

* Fri Jul 17 2009 Christoph Wickert <cwickert@fedoraproject.org> - 0.6.1-1
- Update 0.6.1
- Enable auto (un)mounting using devicekit-disks
- Use new LIB_DIR option instead of PLUGINS_DIR
- Build with "STRIP=0" instead of using nostrip.patch

* Sat May 09 2009 Christoph Wickert <cwickert@fedoraproject.org> - 0.6.0-1
- Update 0.6.0
- Patch to fix segfault in e2_upgrade.so
- Enable the tracker plugin

* Fri May  8 2009 Ville Skyttä <ville.skytta at iki.fi> - 0.5.1-2
- Patch to not strip binaries before rpmbuild creates the -debuginfo subpackage (#499885)

* Wed Feb 25 2009 Christoph Wickert <cwickert@fedoraproject.org> - 0.5.1-1
- Update 0.5.1

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Oct 30 2008 Christoph Wickert <cwickert@fedoraproject.org> - 0.5.0-1
- Update 0.5.0

* Tue Jul 08 2008 Christoph Wickert <cwickert@fedoraproject.org> - 0.4.1-1
- Update 0.4.1
- Revove hal_flags.patch (fixed upstream)
- Remove HAL support until it really works. To enable rebuild "--with hal"

* Wed Apr 02 2008 Christoph Wickert <cwickert@fedoraproject.org> - 0.4.0-1
- Update 0.4.0
- Enable HAL support, but dont install hal by default
- Add emelfm2-0.4-hal_flags.patch (Thanks to Uwe Helm)
- Require bzip2 for the unpack-plugin

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.3.6-2
- Autorebuild for GCC 4.3

* Sun Dec 02 2007 Christoph Wickert <cwickert@fedoraproject.org> - 0.3.6-1
- Update 0.3.6 with upstream's e2-0.3.6-07-12-01.patch
- Enable the ACL plugin

* Tue Aug 21 2007 Christoph Wickert <cwickert@fedoraproject.org> - 0.3.5-2
- Rebuild to fix SELinux issues on PPC32 and to include BuildID feature

* Sun Jul 29 2007 Christoph Wickert <cwickert@fedoraproject.org> - 0.3.5-1
- Update 0.3.5.

* Sat Jun 09 2007 Christoph Wickert <cwickert@fedoraproject.org> - 0.3.4-1
- Update 0.3.4.
- Enable support for inotify

* Wed Mar 21 2007 Christoph Wickert <cwickert@fedoraproject.org> - 0.3.3-1
- Update 0.3.3.

* Sat Feb 24 2007 Christoph Wickert <cwickert@fedoraproject.org> - 0.3.2-2
- Include upstream's e2-0.3.2-07-02-01.patch fixing some bugs.

* Fri Jan 19 2007 Christoph Wickert <cwickert@fedoraproject.org> - 0.3.2-1
- Update 0.3.2.
- Remove Category "Application" from emelfm2.desktop.

* Sat Dec 16 2006 Christoph Wickert <cwickert@fedoraproject.org> - 0.3.1-1
- Update 0.3.1.
- Remove Category "X-Fedora" from emelfm2.desktop.

* Mon Aug 28 2006 Christoph Wickert <cwickert@fedoraproject.org> - 0.3.0-1
- Update 0.3.

* Mon Aug 28 2006 Christoph Wickert <cwickert@fedoraproject.org> - 0.2.0-1
- Update 0.2.0.

* Fri Aug 11 2006 Christoph Wickert <cwickert@fedoraproject.org> - 0.1.8-2
- Include upstream's e2-0.1.8-06-08-09.patch to fix two serious bugs.

* Sun Aug 06 2006 Christoph Wickert <cwickert@fedoraproject.org> - 0.1.8-1
- Update to 0.1.8.

* Thu Apr 23 2006 Christoph Wickert <fedora wickert arcor de> - 0.1.7-1
- Update to 0.1.7.

* Tue Mar 14 2006 Christoph Wickert <fedora wickert arcor de> - 0.1.6-1
- Update to 0.1.6.
- Add Requires for plugins.

* Sat Feb 18 2006 Christoph Wickert <fedora wickert arcor de> - 0.1.5-2
- Rebuild for Fedora Extras 5.

* Thu Jan 26 2006 Christoph Wickert <fedora wickert arcor de> - 0.1.5-1
- Update to 0.1.5.

* Thu Dec 29 2005 Christoph Wickert <fedora wickert arcor de> - 0.1.4-1
- Update to 0.1.4.

* Mon Nov 21 2005 Christoph Wickert <fedora wickert arcor de> - 0.1.3-2
- Removed nonexistant ROADMAP from %%doc.

* Mon Nov 21 2005 Christoph Wickert <fedora wickert arcor de> - 0.1.3-1
- Update to 0.1.3.

* Tue Sep 27 2005 Christoph Wickert <fedora wickert acror de> - 0.1.2-3
- Fix for x86_64.

* Mon Sep 26 2005 Christoph Wickert <fedora wickert acror de> - 0.1.2-2
- Removed broken-icon.patch (using sed instead).
- Removed hardcoded /usr from makefile.config-patch.
- Minor specfile changes (#168608).

* Sun Sep 18 2005 Christoph Wickert <fedora wickert acror de> - 0.1.2-1
- Update to 0.1.2.

* Sun Sep 11 2005 Christoph Wickert <fedora wickert acror de> - 0.1.1-2
- Using destop-file-install.
- Several fixes for FE.

* Sun Aug 21 2005 Christoph Wickert <fedora wickert acror de> - 0.1.1-1.fc4.cw
- Initial RPM release.
